% plot_climateSpace_withSite.m
clear all
close all

%% Description
% *AUTHOR(S):* Philip E. Higuera (phiguera@uidaho.edu)
%
% *DATE CREATED:* 11/2011
%
% *BRIEF DESCRIPTION:*
% Generates plots of climate space, and points in climate space. This is
% specific the WildFIRE PIRE project, as of 1/25/12.
%
% *UPDATES:*
% 9/10/12 by PEH to not plot NPP as a third dimension, in response
% to review comments on McWethy et al., GEB submission. 
%
% 12/17/13 by PEH to exclude Tasmania, and changed lat/lon
% definitions of NZ, S. South America, and PNW.

%% 1. Load T and P data: Global temperature and precipitation data from the Climate Research Unit (New et al. 1999).
% New, M., Hulme, M. & Jones, P. (1999) Representing twentieth century
% spacetime climate variability. Part I: development of
% a 196190 mean monthly terrestrial climatology. Journal of
% Climate, 12, 829856.

load('L:\1_projectsData\Data_climate\CRU\precip.mat')   
            % [mm] Total monthly precip.
load('L:\1_projectsData\Data_climate\CRU\tavg.mat')
            % [C] Mean monthly temperature
Z = meshgrid(y,x);  % [decimal degrees] Lat/lon grid.

%% 2. Load site data: Location of charcoal sites in Version 2 of the Global Charcoal Database 
% (http://www.gpwg.org/gpwgdb.html).

load site_climate
data.site_climate = site_climate;

%% 3. World Map: plot sites on world map, using standard functions from mapping toolbox.

% Set up figure:
    figure(2); clf
    set(gcf,'color','w','units','centimeter','position',...
        [10.2836 11.5307 25.0087 9.9991*0.80])
    fs = 10;    % Font size
    % Lat/lon limits for map:
    latPlot = [-60 60];
    lonPlot = [90 -29.5];
    
% Define regions:
    %%%% Regions used in McWethy et al. 2013:
    % regName = {'Tasmania','New Zealand','Southern S. America',...
    % 'Northwestern U.S.'};
    % latReg = [-44 -39.5; -48 -33; -56 -33; 38 49];
    % lonReg = [144.25 149; 164 180; -76 -70; -125 -105];
    % regCol = [0 0 0; 0 0 0; 0 0 0; 0 0 0];
    % legendLoc = [-42 100; -35 -182; -48 -155; 42 165];
    %%%%
    
    % New regions, as of 12-2013
    regName = {'New Zealand','Southern S. America','Northwestern U.S.'};
    latReg = [-46 -40.5; -44 -40; 43 47];
    lonReg = [167.5 172.5; -72 -71; -124 -122];
    regCol = [0 0 0; 0 0 0; 0 0 0];
    legendLoc = [-35 -182; -48 -155; 42 165];

% Make space to record summary statistics (max, min) for each site-specific
    % cliamte or fire-cliamte variable
    summaryStats = NaN*ones(2,2,length(regName));

% Set up map:
    axesm('miller','MapLatLimit',latPlot,'MapLonLimit',lonPlot,...
       'Frame','on','Grid','on','MeridianLabel','on', ...
       'ParallelLabel','on','fontsize',fs-2)
    setm(gca,'MLabelLocation',60)
    coast = load('coast.mat');
    plotm(coast.lat,coast.long,'k')
    geoshow('landareas.shp', 'FaceColor', [0.75 0.75 0.75])

% Plot sites:
for j = 1:length(regName)
    lat = latReg(j,:);
    lon = lonReg(j,:);
    temp = sum([(site_climate(:,1) <= lat(2)) +...
        (site_climate(:,1) > lat(1)) +...
        (site_climate(:,2) <= lon(2)) +...
        (site_climate(:,2) > lon(1))],2);
    locIn = find(temp == 4);
    plotm(site_climate(locIn,1),site_climate(locIn,2),'.k',...
    'markerfacecolor',regCol (j,:),'markeredgecolor',regCol (j,:),...
    'markersize',5)
    linem([latReg(j,1) latReg(j,2) latReg(j,2) latReg(j,1) latReg(j,1)],...
        [lonReg(j,2),lonReg(j,2),lonReg(j,1),lonReg(j,1),lonReg(j,2)],...
        'color',regCol (j,:),'linewidth',1.5)
    textm(legendLoc(j,1),legendLoc(j,2)+5,regName(j),'fontsize',fs,...
        'fontweight','bold')
    summaryStats(1:2,:,j) = [nanmin(site_climate(locIn,3:4));...
        nanmax(site_climate(locIn,3:4))];  
end
    axis tight
    box off
    framem off
    set(gca,'xcolor','w','ycolor','w','fontsize',8)

%% 4. Plot sites for each region in geographic and climate space. 
figure(3); clf; set(gcf,'color','w','units','centimeter',...
    'position',[10.2836    0.1969   25.0087   11.9246])

% Setup data for use in the custom function "climateSpace_region.m"
    data.x = x;
    data.y = y;
    data.legend_text = {'0' '12.5','25','50','100','200','400','800','1600'};
    data.x_label = ('Mean temperature of the warmest month (\circC)');
    data.y_label = ('Total annual precipitation (mm)');
    data.plot_title = (' ');
    data.bins = [12.5 25 50 100 200 400 800 1600];
        nBins = length(data.bins);
    temp = 0.9.*flipud(summer);
    data.col = temp(1:round(64/(nBins)):end,:);
    data.col = data.col(1:nBins,:);
    data.col = 0.8*ones(nBins,3);

% Define lat. and lon. lines to plot in regional maps
    %%%% As in McWethy et al. 2013:
    %     mline_i = [145 150; 170 180; -65 -75; -110 -120];
    %     pline_i = [-40 -45; -35 -45; -40 -50; 40 50];
    %%%%
    mline_i = [170 180; -65 -75; -110 -120];
    pline_i = [-35 -45; -40 -50; 40 50];

% Create space to save min. (j = 1) and max (j = 2) temperature (i = 1)
% and precipitation (i = 2) data, for each region (k).
regData = NaN(2,2,length(regName));
    
% Plot sites 
for i = 1:length(regName)
    % Map
    subplot(2,4,i)
    latPlot = [latReg(i,1)-1.5 latReg(i,2)+1.5];
    lonPlot = [lonReg(i,1)-1.5 lonReg(i,2)+1.5];
    if i == 3
        latPlot = [latReg(i,1)-2 latReg(i,2)+2];
        lonPlot = [lonReg(i,1)-2 lonReg(i,2)+6];
    end
    axesm('miller','MapLatLimit',latPlot,'MapLonLimit',lonPlot,...
   'Frame','on','Grid','on','MeridianLabel','on',...
   'ParallelLabel','on','fontsize',8)
    mline = mline_i(i,:);
    pline = pline_i(i,:);
    setm(gca,'MLabelLocation',mline,'MLineLocation',mline,...
        'PLabelLocation',pline,'PLineLocation',pline)
    geoshow('landareas.shp', 'FaceColor', [0.75 0.75 0.75])
    axis tight
    hold on
    
    % Make index for sites only in this region
    temp = sum([(site_climate(:,1) <= latReg(i,2)) +...
        (site_climate(:,1) > latReg(i,1)) +...
        (site_climate(:,2) <= lonReg(i,2)) +...
        (site_climate(:,2) > lonReg(i,1))],2);
    locIn = find(temp == 4);
    
    plotm([latReg(i,1) latReg(i,1) latReg(i,2) latReg(i,2) latReg(i,1)],...
        [lonReg(i,1) lonReg(i,2) lonReg(i,2) lonReg(i,1) lonReg(i,1)],...
        'k-','linewidth',2)
    plotm(site_climate(locIn,1),site_climate(locIn,2),'.k')
    box off
    framem off
    set(gca,'xcolor','w','ycolor','w')
    
    % Climate space plot
    data.latReg = latReg(i,:);
    data.lonReg = lonReg(i,:);
    data.regCol = regCol(i,:);
    data.regName = regName(i);

    c_bar = 0;  % Color bar = off. 

    [regData(:,:,i)] = climateSpace_region(data,Z,Z_precip,Z_tavg,[],...
        [2 4 4+i],c_bar);
    set(gca,'color',[1 1 1],'yscale','log')
    set(gcf,'color','w')
    ylim([50 10^4])
    xlim([0 48])
    
    pos = get(gca,'position');
    set(gca,'position',[pos(1) 0.1782 pos(3) pos(4)])
    
    title(' ')
    if i > 1
        ylabel(' ')
        xlabel(' ')
    end
end
    pos = get(gca,'position');
    set(gca,'position',[pos(1) 0.1782 0.1566 0.3412])
    
%% 5. Return max-min (j = 1-2) data for T (i = 1) and P (i = 2), by region (j)    
regData